@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -18,11 +18,13 @@ import os
 import sys
 from os import path
 import re
-from calculate.lib.datavars import (Variable,VariableError,ReadonlyVariable,
-                                    ReadonlyTableVariable,FieldValue)
-from calculate.lib.cl_template import iniParser
-from calculate.lib.utils.files import readLinesFile,isMount,readFile, find
-from calculate.lib.utils.common import getValueFromCmdLine,cmpVersion
+from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
+                                    ReadonlyTableVariable, FieldValue,
+                                    HumanReadable)
+from calculate.lib.cl_ini_parser import iniParser
+from calculate.lib.utils.files import (isMount, readFile, find,
+                                       FindFileType)
+from calculate.lib.utils.common import getValueFromCmdLine
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.variables.user import VariableUrLogin
 from calculate.lib.convertenv import convertEnv
@@ -36,7 +38,10 @@ import pwd
 from calculate.client.client import Client
 
 from calculate.lib.cl_lang import setLocalTranslate
-setLocalTranslate('cl_client3',sys.modules[__name__])
+
+_ = lambda x: x
+setLocalTranslate('cl_client3', sys.modules[__name__])
+
 
 class VariableClRemoteHost(Variable):
     """
@@ -44,6 +49,7 @@ class VariableClRemoteHost(Variable):
     """
     value = ""
 
+
 class VariableClRemoteHostNew(Variable):
     """
     IP or domain name of CDS
@@ -58,22 +64,24 @@ class VariableClRemoteHostNew(Variable):
         self.label = _("Domain IP")
         self.help = _("domain")
 
-    def check(self,value):
+    def check(self, value):
         if self.Get('cl_client_mount_set') == 'off':
             if self.Get('cl_localhost_set') == 'off':
                 if self.Get('cl_remote_host') == '':
                     if not value:
                         raise VariableError(_("Please specify the domain"))
-                    elif not isOpenPort(value,445):
+                    elif not isOpenPort(value, 445):
                         raise VariableError(
                             _("The specified address is not available"))
 
+
 class VariableClRemoteHostLive(ReadonlyVariable):
     """
     Remote host from /proc/cmdline param domain
     """
+
     def get(self):
-        return getValueFromCmdLine("calculate","domain") or ""
+        return getValueFromCmdLine("calculate", "domain") or ""
 
 
 class VariableOsRemoteAuth(Variable):
@@ -101,14 +109,16 @@ class VariableClRemotePw(Variable):
         self.help = _("specify the domain password")
 
     def get(self):
-        return getValueFromCmdLine("calculate","domain_pw") or ""
+        return getValueFromCmdLine("calculate", "domain_pw") or ""
+
 
 class VariableClMovedSkipPath(Variable):
     """
     Skip "Moved" path
     """
     type = "list"
-    value = ['Disks','Home','Moved','FTP','Desktop', 'Share']
+    value = ['Disks', 'Home', 'Moved', 'FTP', 'Desktop', 'Share']
+
 
 class VariableClSyncSkipPath(Variable):
     """
@@ -116,12 +126,13 @@ class VariableClSyncSkipPath(Variable):
     """
     type = "list"
     value = [".googleearth", "Home", "Disks", "FTP",
-        'Share', ".local/share/akonadi/db_data", ".VirtualBox",
-        ".mozilla/firefox/calculate.default/urlclassifier3.sqlite",
-        ".local/share/mime/mime.cache", ".gvfs",
-        ".kde4/share/apps/nepomuk/repository/main/data", ".logout",
-        ".Xauthority", ".thumbnails", ".mozilla/firefox/*/Cache",
-        ".kde4/socket-*", ".cache/", ".local/share/Trash"]
+             'Share', ".local/share/akonadi/db_data", ".VirtualBox",
+             ".mozilla/firefox/calculate.default/urlclassifier3.sqlite",
+             ".local/share/mime/mime.cache", ".gvfs",
+             ".kde4/share/apps/nepomuk/repository/main/data", ".logout",
+             ".Xauthority", ".thumbnails", ".mozilla/firefox/*/Cache",
+             ".kde4/socket-*", ".cache/", ".local/share/Trash"]
+
 
 class VariableClSyncDelPath(Variable):
     """
@@ -131,10 +142,12 @@ class VariableClSyncDelPath(Variable):
     value = [".kde4/share/config/phonondevicesrc",
              ".kde4/cache-*", ".kde4/tmp-*"]
 
+
 class VariableClProfileAllSet(Variable):
     type = "bool"
     value = "off"
 
+
 class VariableClClientSync(Variable):
     type = "bool"
     value = "on"
@@ -146,6 +159,7 @@ class VariableClClientSync(Variable):
         self.label = _("Synchronize the user profile")
         self.help = _("synchronize user preferences")
 
+
 class VariableClLocalhostSet(Variable):
     """
     Using autopartition
@@ -162,24 +176,26 @@ class VariableClLocalhostSet(Variable):
         self.help = _("remove the domain connection settings")
 
     def choice(self):
-        return [("off",_("Domain workstation")),
-                ("on",_("Local workstation"))]
+        return [("off", _("Domain workstation")),
+                ("on", _("Local workstation"))]
 
-    def check(self,value):
+    def check(self, value):
         if self.Get('cl_client_mount_set') == 'off':
             if self.Get('cl_remote_host') == '' and value == "on":
                 raise VariableError(_("The workstation is not in the domain"))
             if self.Get('cl_remote_host') != '' and value == "off":
-                raise VariableError(_("The workstation is already in the domain %s")
-                                %self.Get('cl_remote_host') + "\n" + 
-                                _("Before joining the domain, "
-                                "you need to remove it from the previous domain"))
+                raise VariableError(
+                    _("The workstation is already in the domain %s")
+                    % self.Get('cl_remote_host') + "\n" +
+                    _("Before joining the domain, "
+                      "you need to remove it from the previous domain"))
+
+                # def get(self):
+                #    if self.Get('cl_remote_host') == '':
+                #        return "on"
+                #    else:
+                #        return "off"
 
-    #def get(self):
-    #    if self.Get('cl_remote_host') == '':
-    #        return "on"
-    #    else:
-    #        return "off"
 
 class VariableClClientMountSet(Variable):
     """
@@ -194,7 +210,8 @@ class VariableClClientMountSet(Variable):
         self.label = _("Only mount the domain resource")
         self.help = _("only mount the [remote] domain resource")
 
-class VariableUrUserPw(Variable,LdapHelper):
+
+class VariableUrUserPw(Variable, LdapHelper):
     """
     Current user password
     """
@@ -210,9 +227,8 @@ class VariableUrUserPw(Variable,LdapHelper):
 
     def checkUserPwdLDAP(self, server, userDN, password):
         """Check unix user password on server"""
-        ldapInit = ldap.initialize("ldap://%s"%server)
-        errMessage = ""
-        try: 
+        ldapInit = ldap.initialize("ldap://%s" % server)
+        try:
             ldapInit.bind_s(userDN, password)
         except ldap.INVALID_CREDENTIALS:
             raise VariableError(_("Wrong password"))
@@ -221,7 +237,7 @@ class VariableUrUserPw(Variable,LdapHelper):
             raise VariableError(errMessage)
         return True
 
-    def check(self,value):
+    def check(self, value):
         if not value:
             raise VariableError(_("Empty password"))
         # читаем os_remote_auth, так как при смене пароля
@@ -231,9 +247,10 @@ class VariableUrUserPw(Variable,LdapHelper):
         ldapObj = self.getLdapUserObject()
         if ldapObj:
             usersDN = ldapObj.getUsersDN()
-            userDN = ldapObj.addDN("uid=%s"%self.Get('ur_login'),
-                                            usersDN)
-            self.checkUserPwdLDAP(server,userDN,value)
+            userDN = ldapObj.addDN("uid=%s" % self.Get('ur_login'),
+                                   usersDN)
+            self.checkUserPwdLDAP(server, userDN, value)
+
 
 class VariableUrUserNewPw(Variable):
     """
@@ -249,10 +266,11 @@ class VariableUrUserNewPw(Variable):
         self.label = _("New password")
         self.help = _("new user password")
 
-    def check(self,value):
+    def check(self, value):
         if not value:
             raise VariableError(_("Empty password"))
 
+
 class VariableClClientLogin(VariableUrLogin):
     """
     User Login
@@ -263,30 +281,31 @@ class VariableClClientLogin(VariableUrLogin):
     def choice(self):
         loginChoice = VariableUrLogin.choice(self)
         if self.Get('cl_action') == 'passwd':
-            return filter(lambda x:x != "root",loginChoice)
+            return filter(lambda x: x != "root", loginChoice)
         else:
             return loginChoice
 
-    def check(self,value):
+    def check(self, value):
         """Does user exist"""
         if not value in self.choice() and self.Get('cl_action') == 'logout':
             raise VariableError(_("X session users not found"))
         if value == "":
             raise VariableError(_("Please specify the user"))
         if value == "root" and self.Get('cl_action') == 'passwd':
-            raise VariableError(\
+            raise VariableError(
                 _("This action can be executed by a non-root user only"))
         try:
             pwd.getpwnam(value).pw_gid
-        except:
-            raise VariableError(_("User %s does not exist")%value)
+        except (TypeError, KeyError):
+            raise VariableError(_("User %s does not exist") % value)
 
     def get(self):
-        if (self.Get('cl_action') == 'passwd' and 
-            self.Get('ur_login') != 'root'):
+        if (self.Get('cl_action') == 'passwd' and
+                    self.Get('ur_login') != 'root'):
             return self.Get('ur_login')
         return ""
 
+
 class VariableClClientRelevanceSet(ReadonlyVariable):
     """
     Актуальны ли сейчас выполненные шаблоны
@@ -295,32 +314,36 @@ class VariableClClientRelevanceSet(ReadonlyVariable):
 
     def get(self):
         # если происходят действия ввода или вывода из домена
-        if (self.Get('cl_action') in ("domain","undomain") and
-            self.Get('cl_client_mount_set') == 'off'):
+        if (self.Get('cl_action') in ("domain", "undomain") and
+                    self.Get('cl_client_mount_set') == 'off'):
             return "off"
         # если изменился домен
         if self.Get('cl_remote_host') != self.Get("os_remote_auth"):
             return "off"
         if (self.Get('cl_remote_host') and
-            not isMount(self.Get('cl_client_remote_path'))):
+                not isMount(self.Get('cl_client_remote_path'))):
             return "off"
         return "on"
 
+
 class VariableClClientRemotePath(Variable):
     """
     Путь для монитрования //domain/remote
     """
     value = "/var/calculate/remote"
 
+
 class VariableClClientProfileName(Variable):
     """
     Название удаленного профиля (CLD,CLDX,all)
     """
+
     def get(self):
         return ("all" if self.Get('cl_profile_all_set') == 'on'
                 else self.Get('os_linux_shortname'))
 
-class VariableClLdapData(ldapUser,ReadonlyVariable):
+
+class VariableClLdapData(ldapUser, ReadonlyVariable):
     """
     Внутренняя переменная, содержащая объект для доступа к данным LDAP
     """
@@ -340,7 +363,7 @@ class VariableClLdapData(ldapUser,ReadonlyVariable):
         if usersDN:
             partDN = "ou=Worked,ou=Replication,ou=LDAP"
             servicesDN = "ou=Services"
-            baseDN = usersDN.rpartition(servicesDN+",")[2]
+            baseDN = usersDN.rpartition(servicesDN + ",")[2]
             replDN = self.addDN(partDN, servicesDN, baseDN)
             return replDN
         return False
@@ -352,8 +375,8 @@ class VariableClLdapData(ldapUser,ReadonlyVariable):
             bindDn, bindPw, host = connectData
             replDN = self.getReplDN()
             # find string for service replication branch
-            userAndOsName = "%s@%s"%(userName,osLinuxShort)
-            findAttr = "uid=%s"%userAndOsName
+            userAndOsName = "%s@%s" % (userName, osLinuxShort)
+            findAttr = "uid=%s" % userAndOsName
             # connect to LDAP
             if not self.ldapConnect(bindDn, bindPw, host):
                 return False
@@ -362,14 +385,13 @@ class VariableClLdapData(ldapUser,ReadonlyVariable):
             return resSearch
         return False
 
-    def _gethostbyname(self,hostname):
+    def _gethostbyname(self, hostname):
         try:
             return gethostbyname(hostname)
-        except:
-            pass
-        return None
+        except Exception:
+            return None
 
-    def getNameRemoteServer(self,userName, osLinuxShort, curHost):
+    def getNameRemoteServer(self, userName, osLinuxShort, curHost):
         """
         Get remote domain hostname or empty if profile is keeped on 
         current server
@@ -398,7 +420,7 @@ class VariableClLdapData(ldapUser,ReadonlyVariable):
             usersDN = self.getUsersDN()
             partDN = "ou=Replication,ou=LDAP"
             servicesDN = "ou=Services"
-            baseDN = usersDN.rpartition(servicesDN+",")[2]
+            baseDN = usersDN.rpartition(servicesDN + ",")[2]
             replDN = self.addDN(partDN, servicesDN, baseDN)
             findAttr = "ou=Worked"
             # connect to LDAP
@@ -416,11 +438,13 @@ class VariableClReplicationHost(ReadonlyVariable):
     """
     Удаленный сервер при репликации, который содержит актуальный профиль
     """
+
     def get(self):
         return self.Get('cl_ldap_data').getNameRemoteServer(
-            self.Get('ur_login'),self.Get('cl_client_profile_name'),
+            self.Get('ur_login'), self.Get('cl_client_profile_name'),
             self.Get('cl_remote_host'))
 
+
 class VariableClClientUserMountData(ReadonlyTableVariable):
     """
     Таблица монтирования ресурсов
@@ -430,30 +454,36 @@ class VariableClClientUserMountData(ReadonlyTableVariable):
               'cl_client_user_mount_path',
               'cl_client_user_mount_host']
 
-    def get(self):
+    def get(self, hr=HumanReadable.No):
         home = path.split(self.Get('ur_home_path'))[0]
         envFile = self.Get('cl_env_server_path')
+
         def generate():
-            yield ("share","share",path.join(self.Get('ur_home_path'),"Share"),
-                   self.Get('cl_remote_host'))
-            yield ("unix","unix",path.join(home,".%s"%self.Get('ur_login')),
-                   self.Get('cl_remote_host'))
-            yield ("homes","homes",path.join(self.Get('ur_home_path'),"Home"),
-                   self.Get('cl_remote_host'))
-            if convertEnv().getVar("ftp","host"):
-                yield ("ftp","ftp",path.join(self.Get('ur_home_path'),"FTP"),
-                   self.Get('cl_remote_host'))
+            yield (
+                "share", "share", path.join(self.Get('ur_home_path'), "Share"),
+                self.Get('cl_remote_host'))
+            yield (
+                "unix", "unix", path.join(home, ".%s" % self.Get('ur_login')),
+                self.Get('cl_remote_host'))
+            yield (
+                "homes", "homes", path.join(self.Get('ur_home_path'), "Home"),
+                self.Get('cl_remote_host'))
+            if convertEnv().getVar("ftp", "host"):
+                yield ("ftp", "ftp", path.join(self.Get('ur_home_path'), "FTP"),
+                       self.Get('cl_remote_host'))
             else:
-                yield ("ftp",'','','')
+                yield ("ftp", '', '', '')
             if self.Get('cl_replication_host'):
-                yield ("remote_profile","unix",
-                       path.join(home,".%s.remote"%self.Get('ur_login')),
+                yield ("remote_profile", "unix",
+                       path.join(home, ".%s.remote" % self.Get('ur_login')),
                        self.Get('cl_replication_host'))
             else:
-                yield ("remote_profile",'unix','','')
+                yield ("remote_profile", 'unix', '', '')
+
         return list(generate())
 
-class VariableClClientUserMountName(FieldValue,ReadonlyVariable):
+
+class VariableClClientUserMountName(FieldValue, ReadonlyVariable):
     """
     Название удаленного ресурса
     """
@@ -462,7 +492,7 @@ class VariableClClientUserMountName(FieldValue,ReadonlyVariable):
     column = 0
 
 
-class VariableClClientUserMountResource(FieldValue,ReadonlyVariable):
+class VariableClClientUserMountResource(FieldValue, ReadonlyVariable):
     """
     Название удаленного ресурса
     """
@@ -470,7 +500,8 @@ class VariableClClientUserMountResource(FieldValue,ReadonlyVariable):
     source_variable = "cl_client_user_mount_data"
     column = 1
 
-class VariableClClientUserMountPath(FieldValue,ReadonlyVariable):
+
+class VariableClClientUserMountPath(FieldValue, ReadonlyVariable):
     """
     Путь подключения удаленного ресурса
     """
@@ -478,7 +509,8 @@ class VariableClClientUserMountPath(FieldValue,ReadonlyVariable):
     source_variable = "cl_client_user_mount_data"
     column = 2
 
-class VariableClClientUserMountHost(FieldValue,ReadonlyVariable):
+
+class VariableClClientUserMountHost(FieldValue, ReadonlyVariable):
     """
     Удаленный сервер
     """
@@ -486,12 +518,14 @@ class VariableClClientUserMountHost(FieldValue,ReadonlyVariable):
     source_variable = "cl_client_user_mount_data"
     column = 3
 
-class SyncHelper:
+
+class SyncHelper(object):
     """
     Вспомогательный объект для определения статуса синхронизации и времени
     по конфигурационным файлам
     """
-    def getSyncStatus(self,rpath):
+
+    def getSyncStatus(self, rpath):
         """
         Получить  status_sync из desktop файла
         """
@@ -500,9 +534,9 @@ class SyncHelper:
         if os.path.exists(fileConfig):
             objConfig = iniParser(fileConfig)
             data = self.getDataInConfig("main", ["status_sync"],
-                                                 objConfig)
+                                        objConfig)
             if data:
-                return data.get("status_sync","")
+                return data.get("status_sync", "")
         return ""
 
     def getDataInConfig(self, section, listVars, objConfig):
@@ -511,19 +545,18 @@ class SyncHelper:
         """
         varsConfig = {}
         for varName in listVars:
-            varsConfig[varName] = objConfig.getVar(section,varName)
+            varsConfig[varName] = objConfig.getVar(section, varName)
         if objConfig.getError():
             return False
         return varsConfig
 
-
-    def convertDate(self,strdate,dateformat="%Y-%m-%d %H:%M:%S"):
+    def convertDate(self, strdate, dateformat="%Y-%m-%d %H:%M:%S"):
         """
         Convert date from string format (dateformat) to stuct or None
         """
         if strdate:
             try:
-                return time.strptime(strdate,dateformat)
+                return time.strptime(strdate, dateformat)
             except ValueError:
                 pass
         return ""
@@ -540,73 +573,83 @@ class SyncHelper:
             timeLogout = data["date_logout"]
             timeConfig = data["date"]
             dates = filter(None,
-                    [self.convertDate(timeLogout),
-                     self.convertDate(timeConfig)])
+                           [self.convertDate(timeLogout),
+                            self.convertDate(timeConfig)])
             if dates:
                 return dates[0]
         return ""
 
-    def checkNeedSync(self,homeDir,rpath,curTimeObj,curStatusSync,osLinuxShort):
+    def checkNeedSync(self, homeDir, rpath, curTimeObj, curStatusSync,
+                      osLinuxShort):
         """
         Проверить необходимость синхронизации текущего профиля с удаленным
         """
         # profile directory
-        #fileConfig = os.path.join(homeDir, Client.configFileServer)
+        # fileConfig = os.path.join(homeDir, Client.configFileServer)
         pathProfile = os.path.join(rpath, osLinuxShort)
-        #if readFile(fileConfig).strip():
+        # if readFile(fileConfig).strip():
         #    return True
         fileSoftConfigThis = os.path.join(pathProfile,
-                                      Client.configFileSoft)
+                                          Client.configFileSoft)
         fileSoftConfigCur = os.path.join(homeDir,
-                                      Client.configFileSoft)
-        xSessionCur = iniParser(fileSoftConfigCur).getVar('main','xsession')
-        xSessionThis = iniParser(fileSoftConfigThis).getVar('main','xsession')
+                                         Client.configFileSoft)
+        xSessionCur = iniParser(fileSoftConfigCur).getVar('main', 'xsession')
+        xSessionThis = iniParser(fileSoftConfigThis).getVar('main', 'xsession')
         # check profile date on current server
-        #fileConfigThis = os.path.join(pathProfile, Client.configFileDesktop)
-        #if iniParser(fileConfigThis).getVar('main','status_sync') == "success":
+        # fileConfigThis = os.path.join(pathProfile, Client.configFileDesktop)
+        # if iniParser(fileConfigThis).getVar('main','status_sync') == "success":
         #    self.setVarToConfig("main", {"status_sync":"success_mount"},
         #                        fileConfigThis)
         thisTimeObj = self.getDateObjClientConf(pathProfile)
         if curStatusSync == "success_logout" and \
-            xSessionCur == xSessionThis and \
-            thisTimeObj and curTimeObj and \
-            curTimeObj >= thisTimeObj:
+                        xSessionCur == xSessionThis and \
+                thisTimeObj and curTimeObj and \
+                        curTimeObj >= thisTimeObj:
             return False
         return True
 
-class VariableClClientSyncTime(SyncHelper,ReadonlyVariable):
+
+class VariableClClientSyncTime(SyncHelper, ReadonlyVariable):
     """
     Текущее время синхронизации профиля
     """
+
     def get(self):
         return self.getDateObjClientConf(self.Get('ur_home_path'))
 
-class VariableClClientPackTime(SyncHelper,ReadonlyVariable):
+
+class VariableClClientPackTime(SyncHelper, ReadonlyVariable):
     """
     Время комады упаковки профиля
     """
+
     def get(self):
         return str(float(time.time()))
 
-class VariableClClientSyncStatus(SyncHelper,ReadonlyVariable):
+
+class VariableClClientSyncStatus(SyncHelper, ReadonlyVariable):
     """
     Текущий статус синхронизации профиля
     """
+
     def get(self):
         return self.getSyncStatus(self.Get('ur_home_path'))
 
-class VariableClClientLocalSyncTime(SyncHelper,ReadonlyVariable):
+
+class VariableClClientLocalSyncTime(SyncHelper, ReadonlyVariable):
     """
     Текущий статус синхронизации профиля
     """
+
     def get(self):
         return self.getDateObjClientConf(
-                path.join(
+            path.join(
                 self.Select('cl_client_user_mount_path',
-                    where='cl_client_user_mount_name',eq='unix',
-                    limit=1),self.Get('cl_client_profile_name')))
+                            where='cl_client_user_mount_name', eq='unix',
+                            limit=1), self.Get('cl_client_profile_name')))
 
-class VariableClClientSyncReplicationSet(SyncHelper,ReadonlyVariable):
+
+class VariableClClientSyncReplicationSet(SyncHelper, ReadonlyVariable):
     """
     Нужно ли синхронизировать текущий профиль с удаленным доменом
     """
@@ -616,16 +659,18 @@ class VariableClClientSyncReplicationSet(SyncHelper,ReadonlyVariable):
         if not self.Get('cl_replication_host'):
             return "off"
         profilePath = self.Select('cl_client_user_mount_path',
-                        where='cl_client_user_mount_name',
-                        eq='remote_profile',limit=1)
+                                  where='cl_client_user_mount_name',
+                                  eq='remote_profile', limit=1)
         if self.Get('cl_action') == 'login' and not isMount(profilePath):
             raise VariableError(_("Remote profile not mounted"))
-        return "on" if self.checkNeedSync(self.Get('ur_home_path'),profilePath,
-                    self.Get('cl_client_sync_time'),
-                    self.Get('cl_client_sync_status'),
-                    self.Get('cl_client_profile_name')) else "off"
+        return "on" if self.checkNeedSync(self.Get('ur_home_path'), profilePath,
+                                          self.Get('cl_client_sync_time'),
+                                          self.Get('cl_client_sync_status'),
+                                          self.Get(
+                                              'cl_client_profile_name')) else "off"
 
-class VariableClClientSyncLocalSet(SyncHelper,ReadonlyVariable):
+
+class VariableClClientSyncLocalSet(SyncHelper, ReadonlyVariable):
     """
     Нужно ли синхронизировать текущий профиль с локальным доменом
     """
@@ -635,43 +680,52 @@ class VariableClClientSyncLocalSet(SyncHelper,ReadonlyVariable):
         if not self.Get('cl_remote_host'):
             return "off"
         profilePath = self.Select('cl_client_user_mount_path',
-                        where='cl_client_user_mount_name',
-                        eq='unix',limit=1)
+                                  where='cl_client_user_mount_name',
+                                  eq='unix', limit=1)
         if self.Get('cl_action') == 'login' and not isMount(profilePath):
             raise VariableError(_("Remote profile not mounted"))
-        return "on" if self.checkNeedSync(self.Get('ur_home_path'),profilePath,
-                    self.Get('cl_client_sync_time'),
-                    self.Get('cl_client_sync_status'),
-                    self.Get('cl_client_profile_name')) else "off"
+        return "on" if self.checkNeedSync(self.Get('ur_home_path'), profilePath,
+                                          self.Get('cl_client_sync_time'),
+                                          self.Get('cl_client_sync_status'),
+                                          self.Get(
+                                              'cl_client_profile_name')) else "off"
+
 
 class VariableClClientSymlinks(ReadonlyVariable):
     """
     Список симлинков в пользовательском профиле
     """
+
     def get(self):
         skipFiles = (self.Get('cl_sync_del_path') +
-                    self.Get('cl_sync_skip_path'))
-        reSkip = re.compile("|".join(map(lambda x:x.replace("*",".*"),
-            skipFiles))).search
-        return filter(lambda x:not reSkip(x),
-               find(self.Get('ur_home_path'),onefilesystem=True,filetype='l'))
+                     self.Get('cl_sync_skip_path'))
+        reSkip = re.compile("|".join(map(lambda x: x.replace("*", ".*"),
+                                         skipFiles))).search
+        return filter(lambda x: not reSkip(x),
+                      find(self.Get('ur_home_path'), onefilesystem=True,
+                           filetype=FindFileType.SymbolicLink))
+
 
 class VariableClClientNscdCache(Variable):
     """
     Частота обновления кэша nscd при работе в домене в часах
     """
 
+
 class VariableClCifsVer(ReadonlyVariable):
     """
     Версия модуля CIFS
     """
+
     def get(self):
         return readFile("/sys/module/cifs/version")
 
+
 class VariableClRsyncVer(ReadonlyVariable):
     """
     Версия rsync
     """
+
     def get(self):
         data = isPkgInstalled('net-misc/rsync')
         if data:
