@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -28,6 +28,7 @@ import calculate.client.client as client
 
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 
+_ = lambda x: x
 setLocalTranslate('cl_client3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
@@ -63,15 +64,16 @@ class Wsdl(WsdlBase):
                              ClientError, DesktopError),
             # значения по умолчанию для переменных этого метода
             'setvars': {'cl_action!': 'domain',
-                        'cl_protect_use_set!':'off'
-            },
+                        'cl_protect_use_set!': 'off'
+                        },
             'guivars': {'cl_localhost_set!': lambda dv: (
                 "on" if dv.Get('cl_remote_host') == '' else 'off')},
             # описание груп (список лямбда функций)
             'groups': [
                 lambda group: group(_("Domain"),
                                     normal=(
-                                        'cl_localhost_set', 'cl_remote_host_new',
+                                        'cl_localhost_set',
+                                        'cl_remote_host_new',
                                         'cl_remote_pw'),
                                     expert=('cl_client_mount_set',
                                             'cl_templates_locate',
